@@ -2,10 +2,12 @@ from pathlib import Path
 import os
 import logging
 from abc import ABC, abstractmethod
+import re
 
-from .util import Util
-from .pyamix import PyAMI
-from .ami_sections import AMIFigure, AMIAbsSection
+# local
+
+from py4ami.util import Util
+from py4ami.ami_sections import AMIFigure, AMIAbsSection
 
 
 class AmiProjects:
@@ -87,8 +89,8 @@ class CContainer(ABC):
 
         path in given list OR path is dirx and starts with underscore
         """
-        return file is not None and (file in self.get_reserved_child_files()
-                                     or file in self.get_reserved_child_dirs()
+        return file is not None and (file in self.get_potential_reserved_child_filenames()
+                                     or file in self.get_potential_reserved_child_dirnames()
                                      or self.has_reserved_syntax(file))
 
     @classmethod
@@ -97,17 +99,17 @@ class CContainer(ABC):
 
         Currently must start with "_" and be directory
         """
-        return path.name.startswith("_") and os.path.isdir(path) or \
-            path.name.endswith(".count.xml") or \
-            path.name.endswith(".snippets.xml") or \
-            path.name.endswith(".document.xml")
+        return (path.name.startswith("_") and os.path.isdir(path) or
+                path.name.endswith(".count.xml") or
+                path.name.endswith(".snippets.xml") or
+                path.name.endswith(".document.xml"))
 
     @abstractmethod
-    def get_reserved_child_files(self):
+    def get_potential_reserved_child_filenames(self):
         pass
 
     @abstractmethod
-    def get_reserved_child_dirs(self):
+    def get_potential_reserved_child_dirnames(self):
         pass
 
     @abstractmethod
@@ -125,20 +127,29 @@ class CContainer(ABC):
         return list(files)
 
     def get_children(self) -> list:
-        """lust children as Paths"""
+        """list children as Paths"""
         child_paths = [] if self.dirx is None else list(Path(self.dirx).iterdir())
-        self.logger.debug(f"child[0] {child_paths[0]}")
         return child_paths
 
     def get_child_dirs(self) -> list:
         self.child_dirs = [p for p in self.get_children() if p.is_dir()]
-        self.logger.debug(f"child[0] {self.child_dirs[0]}")
         return self.child_dirs
 
     def get_child_files(self) -> list:
         self.child_files = [p for p in self.get_children() if p.is_file()]
         return self.child_files
 
+    def get_existing_reserved_directory(self, child_name):
+        """get child directory if reserved and exists
+        :param child_name: name in get_potential_reserved_child_dirnames
+        :return: pathname if dir exists else None
+        """
+        if child_name in self.get_potential_reserved_child_dirnames():
+            path = Path(self.pathx, child_name)
+            if path.exists():
+                return path
+        return None
+
     def __repr__(self):
         r = self.dirx.name
         r += f"\ndirs: {len(self.get_child_dirs()) if self.get_child_dirs() is not None else ''}"
@@ -207,10 +218,10 @@ class CProject(CContainer):
         'target',  # delete
     ]
 
-    def get_reserved_child_files(self):
+    def get_potential_reserved_child_filenames(self):
         return self.RESERVED_FILES
 
-    def get_reserved_child_dirs(self):
+    def get_potential_reserved_child_dirnames(self):
         return self.RESERVED_DIRS
 
     def get_name(self):
@@ -255,9 +266,12 @@ class CProject(CContainer):
         fpath = Path(f)
         if not fpath.is_dir():
             return False
-        for c in [CTree.FULLTEXT_PDF, CTree.FULLTEXT_XML, CTree.EUPMC_RESULT_JSON]:
+        for c in CTree.get_potential_reserved_child_filenames():
             if Path(fpath, c).exists():
                 return True
+        for c in CTree.get_potential_reserved_child_dirnames():
+            if Path(fpath, c).is_dir():
+                return True
         cls.logger.warning(f"failed CTree {f}")
         return False
 
@@ -265,9 +279,17 @@ class CProject(CContainer):
 class CTree(CContainer):
     logger = logging.getLogger("ctree")
 
+    # child files
     FULLTEXT_PDF = "fulltext.pdf"
     FULLTEXT_XML = "fulltext.xml"
     EUPMC_RESULT_JSON = 'eupmc_result.json'
+    SCHOLARLY_HTML = 'scholarly.html'
+    # child dirs
+    HTML_DIR = "html"
+    PDFIMAGES_DIR = 'pdfimages'
+    RESULTS_DIR = "results"
+    SECTIONS_DIR = "sections"
+    SVG_DIR = "svg"
 
     def __init__(self, dirx):
         self.logger.debug("CTree ctr")
@@ -278,7 +300,7 @@ class CTree(CContainer):
         EUPMC_RESULT_JSON,
         FULLTEXT_PDF,
         FULLTEXT_XML,
-        'scholarly.html',
+        SCHOLARLY_HTML,
 
         # probably in wrong place
         'search.foo.count.xml',
@@ -290,18 +312,20 @@ class CTree(CContainer):
     ]
 
     RESERVED_DIRS = [
-        'pdfimages',
-        'results',
-        'sections',
-        'svg',
-
+        HTML_DIR,
+        PDFIMAGES_DIR,
+        RESULTS_DIR,
+        SECTIONS_DIR,
+        SVG_DIR,
     ]
 
-    def get_reserved_child_files(self):
-        return self.RESERVED_FILES
+    @classmethod
+    def get_potential_reserved_child_filenames(cls):
+        return cls.RESERVED_FILES
 
-    def get_reserved_child_dirs(self):
-        return self.RESERVED_DIRS
+    @classmethod
+    def get_potential_reserved_child_dirnames(cls):
+        return cls.RESERVED_DIRS
 
     def get_name(self):
         return None if not self.dirx else self.dirx.name
@@ -319,7 +343,7 @@ class CTree(CContainer):
         with open(pp, "w") as p:
             for ff in files:
                 #  filename relative to CTree
-                ll = len(str(self.pathx)+'/')
+                ll = len(str(self.pathx) + '/')
                 self.logger.debug(ff, ll)
                 p.write(f"{str(ff)[ll:]},\n")
 
@@ -355,7 +379,7 @@ class CTree(CContainer):
         """creates sections based on JATS"""
         self.fulltext_xml = Path(self.dirx, self.FULLTEXT_XML)
         if self.fulltext_xml.exists():
-            AMIAbsSection.make_xml_sections(self.fulltext_xml, self.dirx, force)
+            AMIAbsSection.make_xml_sections(self.fulltext_xml, str(self.dirx), force)
 
     @classmethod
     def tests(cls):
@@ -386,6 +410,42 @@ class CTree(CContainer):
         return self.fulltext_xml
 
 
+class CSubDir(CContainer):
+    """manages a descendant directory/subtree of a CTree
+    This is less formalized than cproject and ctree and may change
+    frequently.
+    At the moment (2022-05) there are now "special" subtrees so code is generic
+    """
+    logger = logging.getLogger("subtree")
+
+    def __init__(self, dirx, desc=None):
+        self.logger.debug("CProject ctr")
+        super().__init__(dirx)
+        self.description = desc
+        self.files = None
+        self.dirs = None
+
+    def get_name(self):
+        return None
+
+    def get_potential_reserved_child_dirnames(self):
+        return []
+
+    def get_potential_reserved_child_filenames(self):
+        return []
+
+    def get_child_files_by_name(self, regex=None):
+        """list child files and directories, optionally filter by regex
+        matching is on the basename, not the complete filename
+        Note that "." is a regex metacharacter and needs escaping with \
+        :param regex: regex matching basename"""
+        files = self.get_child_files()
+        if regex:
+            p = re.compile(regex)
+            files = [f for f in files if p.match(os.path.basename(f))]
+        return files
+
+
 class CProjectTests:
     logger = logging.getLogger("section_glob")
     logger.setLevel(logging.INFO)
@@ -492,14 +552,6 @@ class CProjectTests:
         project = CProject(AmiProjects.C_LIION4)
         project.make_jats_sections(force=True)
 
-    @classmethod
-    def test_captions_oil186(cls):
-        c_project = CProject(Path("/Users/pm286/projects/CEVOpen/searches/oil186"))
-        dirx = c_project.dirx
-        print(f"dirx {dirx}")
-        PyAMI().run_command(f"--proj {dirx} --split xml2sect")
-        cls.print_fig_caption(c_project, cls.FIGURE_OLD)
-
     @classmethod
     def print_fig_caption(cls, project, fig_type):
         for ctree in project.get_ctrees():
