@@ -11,14 +11,16 @@ import re
 import logging
 logging.info(f"loading {__file__}")
 
-try:
-    from ..py4ami.dict_lib import AMIDict, AMIDictError, Entry
-    logging.info(f"loaded py4ami.dict_lib")
-except Exception:
-    try:
-        from py4ami.dict_lib import AMIDict, AMIDictError, Entry
-    except Exception as e:
-        logging.severe(f"Cannot import from py4ami.dict_lib")
+from py4ami.ami_dict import AMIDict, AMIDictError, Entry
+
+# try:
+#     from py4ami.ami_dict import AMIDict, AMIDictError, Entry
+#     logging.info(f"loaded py4ami.ami_dict")
+# except Exception:
+#     try:
+#         from py4ami.ami_dict import AMIDict, AMIDictError, Entry
+#     except Exception as e:
+#         logging.error(f"Cannot import from py4ami.ami_dict")
 
 
 # from py4ami.wikimedia import WikidataLooku
@@ -325,11 +327,12 @@ def test_add_list_of_entries_from_list_of_string_with_duplicates_and_replace():
 
 
 def test_add_list_of_entries_from_list_of_string_with_duplicates_and_no_replace():
+    """add list of terms which contains duplicate and raise error"""
     terms = ["foo", "bar", "plugh", "xyzzy", "bar"]
     amidict = AMIDict.create_minimal_dictionary()
     try:
         amidict.create_and_add_entries_from_str_list(terms, replace=False)
-        assert False, f"AMIDict duplicate error should have been thrown"
+        assert False, f"AMIDict duplicate error (bar) should have been thrown"
     except AMIDictError:
         assert True, "error should have been throwm"
     assert amidict.get_entry_count() == 4, f"'bar' should be present"
